from typing import Tuple, List
import sys
import asyncio
import traceback
import nonebot
from nonebot.log import logger
from nonebot.adapters.onebot.v11 import MessageSegment
from .basicFunc import *
from .exception import *
from .bili_client import bili_client
from .bili_task import bili_task_manager

__PLUGIN_NAME = "[bilibilibot~番剧]"
    
async def check_telegram_update():
    """
    @description  :
    检查数据库中的每一个影视节目是否更新，如果更新则向用户发送通知，并且更新文件
    ---------
    @param  :
    无
    -------
    @Returns  :
    无
    -------
    """
    
    telegram_list = list(bili_task_manager.telegram_list.values())
    sched_bot = nonebot.get_bot()
    results = await asyncio.gather(
        *[bili_client.get_telegram_latest_episode(telegram_info["season_id"], telegram_info["episode"]) for telegram_info in telegram_list],
        return_exceptions=True
    )

    for i in range(len(telegram_list)):
        if isinstance(results[i], tuple):
            if results[i][0] is True:
                logger.info(f'[{__PLUGIN_NAME}]检测到影视剧 <{telegram_list[i]["telegram_title"]}> 更新')
                text_msg = "【B站动态】\n《{}》已更新第{}集\n标题: {}\n链接: {}\n".format(
                        telegram_list[i]["telegram_title"], results[i][1], results[i][2], results[i][3]
                    )
                bili_task_manager.update_telegram_info(telegram_list[i]["season_id"], results[i][1], results[i][5])
                cover_msg = MessageSegment.image(results[i][4])
                reported_msg = text_msg + cover_msg
                logger.info(f'[{__PLUGIN_NAME}]向关注用户发送更新通知')

                # 通知用户
                user_list = telegram_list[i]["user_follower"]
                await asyncio.gather(*[sched_bot.send_msg(message=reported_msg, user_id=user_id) for user_id in user_list])
            
                group_list = telegram_list[i]["group_follower"]
                await asyncio.gather(*[sched_bot.send_msg(message=reported_msg, group_id=group_id) for group_id in group_list])
            
        elif isinstance(results[i], (BiliAPIRetCodeError, BiliStatusCodeError, BiliConnectionError)):
            exception_msg = f'[错误报告]\n检测番剧 <{telegram_list[i]["telegram_title"]}> 更新情况时发生错误\n错误类型: {type(results[i])}\n错误信息: {results[i]}'
            logger.error(f"[{__PLUGIN_NAME}]" + exception_msg)
        
async def follow_telegram(id_prefix: str, telegram_id: int, user_id: str, user_type: int) -> Tuple[bool, str]:
    '''根据用户关注节目，修改节目的文件

    Args:
        id_prefix (str): ep | ss | md
        telegram_id (int): 节目的id
        user_id (str): 用户的qq号/群号
        user_type (int): 0-个人用户，1-群号

    Returns:
        Tuple[bool, str]: [是否成功，信息]
    '''
    
    try:
        if id_prefix == "ep":
            res = await bili_client.init_telegram_info_by_ep_id(telegram_id)
        elif id_prefix == "ss":
            res = await bili_client.init_telegram_info_by_season_id(telegram_id)
        elif id_prefix == "md":
            res = await bili_client.init_telegram_info_by_media_id(telegram_id)
        else:
            return (False, telegram_id + "(番剧id错误)")
        
        season_id, telegram_title, episode, is_finish = res
        season_id = str(season_id)
        logger.debug(f'{__PLUGIN_NAME}{bili_task_manager.telegram_list}')
        
        if season_id not in bili_task_manager.telegram_list:
            logger.debug(f'{__PLUGIN_NAME}{season_id}不在任务列表中存在')
            bili_task_manager.add_telegram_info(season_id, telegram_title, episode, is_finish)
            if user_type == 0:
                bili_task_manager.add_user_follower(2, season_id, user_id)
            else:
                bili_task_manager.add_group_follower(2, season_id, user_id)
            
            logger.info(f"[{__PLUGIN_NAME}]用户/群 <{user_id}> 关注番剧 <{telegram_title}> 成功")
            return (True, telegram_title + f"(season_id: {season_id})")
        
        if user_type == 0 and user_id in bili_task_manager.telegram_list[season_id]["user_follower"] or \
            user_type == 1 and user_id in bili_task_manager.telegram_list[season_id]["group_follower"]:
            logger.debug(f'{__PLUGIN_NAME}番剧 <{bili_task_manager.telegram_list[season_id]["telegram_title"]}> 已关注')
            return (False, season_id + "(已关注)")

        logger.debug(f'{__PLUGIN_NAME}进行关注{season_id}')
        
        if user_type == 0:
            bili_task_manager.add_user_follower(2, season_id, user_id)
        else:
            bili_task_manager.add_group_follower(2, season_id, user_id)
        logger.info(f"[{__PLUGIN_NAME}]用户/群 <{user_id}> 关注番剧 <{telegram_title}> 成功")
        return (True, telegram_title + f"(season_id: {season_id})")
 
    except BiliAPI404Error:
        return (False, f"{id_prefix}{telegram_id}" + "(番剧id错误)")
    except (BiliConnectionError, BiliAPIRetCodeError, BiliStatusCodeError):
        ex_type, ex_val, _ = sys.exc_info()
        exception_msg = f'【错误报告】\n获取番剧 <{id_prefix}{telegram_id}> 信息发生错误\n错误类型: {ex_type}\n错误值: {ex_val}\n'
        logger.error(f"[{__PLUGIN_NAME}]" + exception_msg + traceback.format_exc())
        return (False, f"{id_prefix}{telegram_id}" + "(网络错误)")
    except BiliDatebaseError:
        ex_type, ex_val, _ = sys.exc_info()
        exception_msg = f'【错误报告】\n关注番剧 <{season_id}> 时数据库发生错误\n错误类型: {ex_type}\n错误值: {ex_val}\n'
        logger.error(f"[{__PLUGIN_NAME}]" + exception_msg + traceback.format_exc())
        return (False, season_id + "(数据库错误)")
    except Exception:
        ex_type, ex_val, _ = sys.exc_info()
        exception_msg = f'【错误报告】\n关注番剧 <{id_prefix}{telegram_id}> 时发生意料之外的错误\n错误类型: {ex_type}\n错误值: {ex_val}\n'
        logger.error(f"[{__PLUGIN_NAME}]" + exception_msg + traceback.format_exc())
        return (False, f"{id_prefix}{telegram_id}" + "(未知错误,请查看日志)")
        
async def unfollow_telegram(season_id: str, user_id: str, user_type: int) -> Tuple[bool, str]:
    '''根据用户/群取关节目，修改节目文件

    Args:
        season_id (str): 节目的ID
        user_id (str): 用户qq号/群号
        user_type (int): 0-个人用户，1-群号

    Returns:
        Tuple[bool, str]: [是否成功, 信息]
    '''
    if season_id[:2] != "ss" and not season_id[2:].isdigit():
        return (False, season_id + "(错误参数)")
    
    season_id = season_id[2:]
    logger.debug(f'{__PLUGIN_NAME}{bili_task_manager.telegram_list}')
    
    try:
        if season_id not in bili_task_manager.telegram_list or \
            user_type == 0 and user_id not in bili_task_manager.telegram_list[season_id]["user_follower"] or \
            user_type == 1 and user_id not in bili_task_manager.telegram_list[season_id]["group_follower"]:
            logger.info(f'{__PLUGIN_NAME}用户/群 <{user_id}> 未关注番剧 <{season_id}>')
            return (False, season_id + "(未关注)")

        telegram_title = bili_task_manager.telegram_list[season_id]["telegram_title"]
        if user_type == 0:
            bili_task_manager.remove_user_follower(2, season_id, user_id)
        else:
            bili_task_manager.remove_group_follower(2, season_id, user_id)
        
        return (True, telegram_title + f"(season_id: ss{season_id})")
        
    except BiliDatebaseError:
        ex_type, ex_val, _ = sys.exc_info()
        exception_msg = f'【错误报告】\n取关番剧 <{season_id}> 时数据库发生错误\n错误类型: {ex_type}\n错误值: {ex_val}\n'
        logger.error(f"[{__PLUGIN_NAME}]" + exception_msg + traceback.format_exc())
        return (False, season_id + "(数据库错误)")
    
async def follow_telegram_list(
    user_id: int, 
    telegram_id_list: List[str],
    user_type: int
    ) -> List[List[str]]:
    '''个人用户/群关注番剧

    Args:
        user_id (int): qq号/群号
        telegram_id_list (List[str]): 关注的番剧号
        user_type (int): 0-个人用户，1-群

    Returns:
        List[List[str]]: [是否成功，信息]
    '''
    # 在该函数中同时对telegram_id, season_id, media_id进行区分和统一处理
    success_list = []
    fail_list = []
    prefix_type = ('ep', 'ss', "md")
    valid_telegram_id_list = []
    for telegram_id in telegram_id_list:
        logger.debug(f'{__PLUGIN_NAME}telegram_id = {telegram_id}')
        
        if telegram_id[:2] not in prefix_type or not telegram_id[2:].isdigit():
            fail_list.append(telegram_id + "(错误参数)")
        else:
            valid_telegram_id_list.append(telegram_id)
    logger.debug(f'{__PLUGIN_NAME}valid list = {valid_telegram_id_list}')
    
    results = await asyncio.gather(
        *[follow_telegram(telegram_id[:2], int(telegram_id[2:]), str(user_id), user_type) for telegram_id in valid_telegram_id_list],
        return_exceptions=True
    )

    for is_success, msg in results:
        if is_success:
            success_list.append(msg)
        else:
            fail_list.append(msg)
    
    return [success_list, fail_list] 

async def unfollow_telegram_list(
    user_id: int, 
    season_id_list: List[str],
    user_type: int
    ) -> List[List[str]]:
    '''个人用户/群取关番剧

    Args:
        user_id (int): qq号/群号
        season_id_list (List[str]): 取关的番剧号
        user_type (int): 0-个人用户，1-群

    Returns:
        List[List[str]]: [是否成功，信息]
    '''
    success_list = []
    fail_list = []

    for season_id in season_id_list:
        isSuccess, s = await unfollow_telegram(season_id, str(user_id), user_type)
        if isSuccess:
            success_list.append(s)
        else:
            fail_list.append(s)
    
    return [success_list, fail_list]                 
                

            
            

        
    
            



from .exception import BiliConnectionError, BiliDatebaseError
import asyncio
from typing import Tuple, List
import sys
import traceback
import nonebot
from nonebot.log import logger
from nonebot.adapters.onebot.v11 import MessageSegment
from .basicFunc import *
from .bili_client import bili_client
from .bili_task import bili_task_manager

__PLUGIN_NAME = "[bilibilibot~视频]"

# 视频
async def check_up_update() -> None:
    """
    @description  :
    检查关注UP主是否更新新视频，如果更新则通知用户并写入文件
    ---------
    @param  :
    -------
    @Returns  :
    -------
    """
    schedBot = nonebot.get_bot()
    #assert status == True, "数据库发生错误"
    check_up_list = bili_task_manager.get_up_check_update_list()
    #logger.debug(f'{__PLUGIN_NAME}check_up_list = {check_up_list}')
    
    results = await asyncio.gather(
        *[bili_client.get_latest_video(uid, bili_task_manager.up_list[uid]["latest_timestamp"]) for uid in check_up_list],
        return_exceptions=True
    )
    
    for i in range(len(check_up_list)):
        if isinstance(results[i], tuple):
            if results[i][0] is True:
                up_uid = check_up_list[i]
                up_name = bili_task_manager.up_list[up_uid]["up_name"]

                logger.info(f'{__PLUGIN_NAME}检测到up主<{up_name}>更新了视频')
                textMsg = f"【B站动态】\n <{up_name}> 更新了视频\n标题: {results[i][2]}\n链接: https://www.bilibili.com/video/{results[i][1]}"
                
                bili_task_manager.update_up_info(up_uid, results[i][3])

                user_list = bili_task_manager.up_list[up_uid]["user_follower"]
                for user_id in user_list:
                    await schedBot.send_msg(message=textMsg + MessageSegment.image(results[i][4]), user_id=user_id)
                
                group_list = bili_task_manager.up_list[up_uid]["group_follower"]
                for group_id in group_list:
                    await schedBot.send_msg(message=textMsg + MessageSegment.image(results[i][4]), group_id=group_id)
        elif isinstance(results[i], (BiliAPIRetCodeError, BiliStatusCodeError, BiliConnectionError)):
            exception_msg = f'[错误报告]\n检测up主 <{check_up_list[i]}> 更新情况时发生错误\n错误类型: {type(results[i])}\n错误信息: {results[i]}'
            logger.error(f"[{__PLUGIN_NAME}]" + exception_msg)

async def follow_up(uid: str, user_id: str, user_type: int) -> Tuple[bool, str]:
    '''根据用户或群关注up，修改数据库

    Args:
        uid (str): up的uid
        user_id (str): 用户的qq或群号
        user_type (int): 0-个人用户，1-群

    Returns:
        Tuple[bool, str]: [是否成功，信息]
    '''
    
    # 处理参数错误
    if not uid.isdigit():
        logger.error(f'{__PLUGIN_NAME}存在错误参数<{uid}>')
        return (False, uid + "(错误参数)")
    
    uid = str(int(uid))
    
    try:
        
        # up信息不存在于数据库,对数据库进行更新
        if uid not in bili_task_manager.up_list:
            up_name, latest_timestamp = await bili_client.init_up_info(uid)
            
            if up_name:
                bili_task_manager.add_up_info(uid, up_name, latest_timestamp)
                if user_type == 0:
                    bili_task_manager.add_user_follower(0, uid, user_id)
                else:
                    bili_task_manager.add_group_follower(0, uid, user_id)
               
                logger.info(f"{__PLUGIN_NAME}用户/群 <{user_id}> 关注主播 <{up_name}> 成功")
                return (True, up_name + f"(uid: {uid})")
            else:
                logger.info(f'{__PLUGIN_NAME}up({uid})不存在，请检查uid')
                return (False, uid + "(uid错误)")
        up_name = bili_task_manager.up_list[uid]["up_name"]
        # 处理已关注
        if user_type == 0 and user_id in bili_task_manager.up_list[uid]["user_follower"] or \
            user_type == 1 and user_id in bili_task_manager.up_list[uid]["group_follower"]:
            logger.info(f"{__PLUGIN_NAME}用户/群 <{user_id}> 已经关注了up <{up_name}>")
            return (False, up_name + "(已关注)")

        # 进行关注
        if user_type == 0:
            bili_task_manager.add_user_follower(0, uid, user_id)
        elif user_type == 1:
            bili_task_manager.add_group_follower(0, uid, user_id)
        logger.info(f"{__PLUGIN_NAME}用户/群 <{user_id}> 关注up <{up_name}> 成功")
        return (True, up_name + f"(uid: {uid})")
    except BiliAPI404Error:
        return (False, uid + "(uid错误)")
    except (BiliConnectionError, BiliAPIRetCodeError, BiliStatusCodeError):
        ex_type, ex_val, _ = sys.exc_info()
        exception_msg = f'【错误报告】\n获取up主 <{uid}> B站信息发生错误\n错误类型: {ex_type}\n错误值: {ex_val}\n'
        logger.error(f"{__PLUGIN_NAME}" + exception_msg + traceback.format_exc())
        return (False, uid + "(网络错误)")
    except BiliDatebaseError:
        ex_type, ex_val, _ = sys.exc_info()
        exception_msg = f'【错误报告】\n关注up主 <{uid}>时数据库发生错误\n错误类型: {ex_type}\n错误值: {ex_val}\n'
        logger.error(f"{__PLUGIN_NAME}" + exception_msg + traceback.format_exc())
        return (False, uid + "(数据库错误)")
    except Exception:
        ex_type, ex_val, _ = sys.exc_info()
        exception_msg = f'【错误报告】\n关注up主 <{uid}>时发生意料之外的错误\n错误类型: {ex_type}\n错误值: {ex_val}\n'
        logger.error(f"{__PLUGIN_NAME}" + exception_msg + traceback.format_exc())
        return (False, uid + "(未知错误,请查看日志)")

async def unfollow_up(uid: str, user_id: str, user_type: int) -> Tuple[bool, str]:
    '''根据个人用户或群取关up主，修改up文件

    Args:
        uid (str): up的uid
        user_id (str): 用户的qq号/群号
        user_type (int): 0-个人用户，1-群

    Returns:
        Tuple[bool, str]: [是否成功，信息]
    '''
    
    # 处理参数错误
    if not uid.isdigit():
        logger.error(f'{__PLUGIN_NAME}存在错误参数 <{uid}>')
        return (False, uid + "(错误参数)")
    try:
    # 处理未关注
        logger.debug(f"{uid}的关注列表{bili_task_manager.up_list[uid]['user_follower']}")
        if uid not in bili_task_manager.up_list or \
            user_type == 0 and user_id not in bili_task_manager.up_list[uid]["user_follower"] or \
            user_type == 1 and user_id not in bili_task_manager.up_list[uid]["group_follower"]:
            logger.info(f'{__PLUGIN_NAME}用户/群 <{user_id}> 未关注up <{uid}>')
            return (False, uid + "(未关注)")
        
        # 进行取关
        up_name = bili_task_manager.up_list[uid]["up_name"]
        if user_type == 0:
            bili_task_manager.remove_user_follower(0, uid, user_id)
        else:
            bili_task_manager.remove_group_follower(0, uid, user_id)
        logger.info(f'{__PLUGIN_NAME}用户/群 <{user_id}> 取关up <{uid}> 成功')

        return (True, up_name  + f"(uid: {uid})") 
    except BiliDatebaseError:
        ex_type, ex_val, _ = sys.exc_info()
        exception_msg = f'【错误报告】\n取关up主 <{uid}> 时数据库发生错误\n错误类型: {ex_type}\n错误值: {ex_val}\n'
        logger.error(f"{__PLUGIN_NAME}" + exception_msg + traceback.format_exc())
        return (False, uid + "(数据库错误)")

async def follow_up_list(
    user_id: int, 
    uid_list: List[str], 
    user_type: int
    ) -> List[List[str]]:
    '''个人用户/群关注up主

    Args:
        user_id (int): qq号/群号
        uid_list (List[str]): up主的uid
        user_type (int): 0-个人用户，1-群        

    Returns:
        List[List[str]]: [[关注成功列表]，[关注失败列表]]
    '''
    successList = []
    failList = []
    
    for uid in uid_list:
        isSuccess, s = await follow_up(uid, str(user_id), user_type)
        if isSuccess:
            successList.append(s)
        else:
            failList.append(s)

    return [successList, failList]

async def unfollow_up_list(
    user_id: int, 
    uid_list: List[str],
    user_type: int
    ) -> List[List[str]]:
    '''个人用户/群取关up主

    Args:
        user_id (int): qq号/群号
        uid_list (List[str]): 取关的up主
        user_type (int): 0-个人用户，1-群

    Returns:
        List[List[str]]: [是否成功，信息]
    '''
    successList = []
    failList = []

    for uid in uid_list:
        isSuccess, s = await unfollow_up(uid, str(user_id), user_type)
        if isSuccess:
            successList.append(s)
        else:
            failList.append(s)
    
    return [successList, failList]


import asyncio
#from .db import bili_database
#from .exception import BiliConnectionError, BiliDatebaseError
import httpx
import json
from typing import Dict, Tuple, List
import sys
import traceback
import nonebot
from nonebot.log import logger
from nonebot.adapters.onebot.v11 import MessageSegment
#import basicFunc
#from .basicFunc import *

__PLUGIN_NAME = "B站整合~动态"
GET_NEWS_BY_UID_API = "https://api.bilibili.com/x/polymer/web-dynamic/v1/feed/space?host_mid={}&timezone_offset=-480"
DYNAMIC_DETAIL_URL = "https://t.bilibili.com/{}"
header = {
    'User-Agent':'Mozilla/5.0 (Windows NT 6.1; rv2.0.1) Gecko/20100101 Firefox/4.0.1'
}

async def get_latest_news(uid: str, pin_news_id: str, record_timestamp: int) -> Tuple[str, List[Dict]]:
    '''根据uid获取最新的动态

    Args:
        uid (str): 查询的uid
        pin_news_id (str): 数据库中记录置顶动态的id,无则返为""
        record_timestamp (int): 数据库中记录最新动态的时间戳

    Returns:
        Tuple[str, Dict]: 
        str - 置顶动态id
        List[Dict] - 更新的动态内容
    ''' 
    
    try:
        async with httpx.AsyncClient() as client:
            response = await client.get(url=GET_NEWS_BY_UID_API.format(uid), headers=header)
    except Exception as e:
        pass
        raise BiliConnectionError(f"获取用户 <{uid}> 的动态时发生网络错误:{e.args[0]}")
    if response.status_code != 200:
        pass
        raise BiliConnectionError(f"获取用户 <{uid}> 的动态时连接出错:状态码={response.status_code}")
    response: Dict = response.json()
    if response["code"] != 0:
        raise BiliConnectionError(f"获取用户 <{uid}> 的动态时发生错误:{response['message']}")
    
    news_list: List = response["data"]["items"]

    # 如果动态列表长度为0则直接返回
    if len(news_list) == 0:
        return ("", [])
    
    update_news_list = []
    has_pin_news = 0
    top_news_id = ""

    # 处理置顶动态
    top_news = news_list[0]
    if "module_tag" in top_news["modules"] and top_news["modules"]["module_tag"]["text"] == "置顶":
        # 如果存在置顶动态,判断与数据库中记录的是否相同
        has_pin_news = 1
        top_news_id: str = top_news["id_str"]
        if top_news_id == pin_news_id:
            # 如果相同,则跳过该动态
            pass
        else:
            # 如果置顶动态发生更换
            # 处理置顶旧动态的情况,如果置顶旧动态,则不需要更新通知;
            logger.debug(f'{__PLUGIN_NAME} <{uid}> 的置顶动态发生变化,由{pin_news_id}变为{top_news_id}')
            major_module: Dict = top_news["modules"]["module_dynamic"]["major"]
            additional_module: Dict = top_news["modules"]["module_dynamic"]["additional"]
            desc_module: Dict  = top_news["modules"]["module_dynamic"]["desc"]
            top_news_timestamp: int = top_news["modules"]["module_author"]["pub_ts"]
            top_news_major_type = major_module["type"] if major_module else "MAJOR_TYPE_NONE"
            top_news_add_type = additional_module["type"] if additional_module else "ADDITIONAL_TYPE_NONE"

            if top_news_timestamp > record_timestamp:
                # 置顶动态是新动态,需要通知
                temp_news = {}
                temp_news["tag"] = "NORMAL"
                temp_news["news_id"] = top_news_id
                temp_news["text"] = desc_module["text"] if desc_module else ""
                temp_news["image"] = []
                temp_news["timestamp"] = top_news_timestamp

                if top_news_major_type == "MAJOR_TYPE_DRAW":
                    for image_item in major_module["draw"]["items"]:
                        temp_news["image"].append(image_item["src"])
                elif top_news_major_type == "MAJOR_TYPE_ARTICLE":
                    temp_news["tag"] = "MAJOR_ARTICLE"
                    temp_news["article"] = {
                        "title": major_module["article"]["title"],
                        "cover": major_module["article"]["covers"][0],
                        "jump_url": major_module["article"]["jump_url"]
                    }
                if top_news_add_type == "ADDITIONAL_TYPE_VOTE":
                    temp_news["tag"] = "ADD_VOTE"
                    temp_news["vote"] = {
                        "desc": additional_module["vote"]["desc"],
                        "vote_id": additional_module["vote"]["vote_id"]
                    }
                elif top_news_add_type == "ADDITIONAL_TYPE_UGC":
                    temp_news["tag"] = "ADD_UGC"
                    temp_news["tgc"] = {
                        "title" : additional_module["ugc"]["title"],
                        "jump_url": additional_module["ugc"]["jump_url"],
                        "cover": additional_module["ugc"]["cover"]
                    }
                elif top_news_add_type == "ADDITIONAL_TYPE_RESERVE":
                    temp_news["tag"] = "ADD_RESERVE",
                    temp_news["reserve"] = {
                        "title": additional_module["reserve"]["title"],
                        "desc": additional_module["reserve"]["desc1"]["text"]
                    }
                    
                if top_news_major_type in ("MAJOR_TYPE_DRAW", "MAJOR_TYPE_NONE", "MAJOR_TYPE_ARTICLE"):
                    update_news_list.append(temp_news)
                    print(json.dumps(temp_news, ensure_ascii=False, indent=4))
    
    # 处理置顶动态外的动态
    for news_item in news_list[has_pin_news:]:
        news_id = news_item["id_str"]
        major_module: Dict = news_item["modules"]["module_dynamic"]["major"]
        additional_module: Dict = news_item["modules"]["module_dynamic"]["additional"]
        desc_module: Dict  = news_item["modules"]["module_dynamic"]["desc"]
        news_item_major_type = major_module["type"] if major_module else "MAJOR_TYPE_NONE"
        news_item_add_type = additional_module["type"] if additional_module else "ADDITIONAL_TYPE_NONE"
        news_timestamp = news_item["modules"]["module_author"]["pub_ts"]
        
        if news_timestamp <= record_timestamp:
            break
        # 发现新动态
        logger.debug(f'{__PLUGIN_NAME} <{uid}> 更新了动态 {news_id}')
        temp_news = {}
        temp_news["tag"] = "NORMAL"
        temp_news["news_id"] = news_id
        temp_news["text"] = desc_module["text"] if desc_module else ""
        temp_news["image"] = []
        temp_news["timestamp"] = news_timestamp

        if news_item_major_type == "MAJOR_TYPE_DRAW":
            for image_item in major_module["draw"]["items"]:
                temp_news["image"].append(image_item["src"])
        elif news_item_major_type == "MAJOR_TYPE_ARTICLE":
            temp_news["tag"] = "MAJOR_ARTICLE"
            temp_news["article"] = {
                "title": major_module["article"]["title"],
                "cover": major_module["article"]["covers"][0],
                "jump_url": major_module["article"]["jump_url"]
            }
        if news_item_add_type == "ADDITIONAL_TYPE_VOTE":
            temp_news["tag"] = "ADD_VOTE"
            temp_news["vote"] = {
                "desc": additional_module["vote"]["desc"],
                "vote_id": additional_module["vote"]["vote_id"]
            }
        elif news_item_add_type == "ADDITIONAL_TYPE_UGC":
            temp_news["tag"] = "ADD_UGC"
            temp_news["tgc"] = {
                "title" : additional_module["ugc"]["title"],
                "jump_url": additional_module["ugc"]["jump_url"],
                "cover": additional_module["ugc"]["cover"]
            }
        elif news_item_add_type == "ADDITIONAL_TYPE_RESERVE":
            temp_news["tag"] = "ADD_RESERVE",
            temp_news["reserve"] = {
                "title": additional_module["reserve"]["title"],
                "desc": additional_module["reserve"]["desc1"]["text"]
            }
            
        if news_item_major_type in ("MAJOR_TYPE_DRAW", "MAJOR_TYPE_NONE", "MAJOR_TYPE_ARTICLE"):
            update_news_list.append(temp_news)
            print(json.dumps(temp_news, ensure_ascii=False, indent=4))
    
    return (top_news_id, update_news_list)

loop = asyncio.get_event_loop()
tasks = [get_latest_news("6700458", "", 0)]
loop.run_until_complete(asyncio.wait(tasks))

                


    










